package com.brilliance.isc.transfer.transaction;

import com.brilliance.isc.bo.lg.GetcanStoreBo;
import com.brilliance.isc.transfer.IBaseStructMapper;
import com.brilliance.isc.transfer.model.*;
import com.brilliance.isc.vo.lg.GetcanStoreVo;
import org.mapstruct.*;
import org.mapstruct.factory.Mappers;


/**
 * Getcan Bo、Vo之间的转换处理类。如果有很复杂的函数，则可以用适配器模式重写
 */
@Mapper(componentModel = "spring",uses = {
        IGctMapper.class, IGitMapper.class,
        INitMapper.class, INctMapper.class, IOtherModMapper.class}
        )
public interface GetcanStructMapper extends IBaseStructMapper<GetcanStoreBo, GetcanStoreVo> {

    /**
     * 此行语句一定要写，StructMapper需要
     */
    GetcanStructMapper INSTANCE = Mappers.getMapper(GetcanStructMapper.class);

    /**
     * Vo转为Bo
     *
     * @param vo
     * @return 返回业务Bo
     */
    @Override
    GetcanStoreBo voTransferToBo(GetcanStoreVo vo);

    /**
     * Vo追加更新至Bo
     * 忽略oldgrp的复制
     * @param vo
     * @param bo
     */
    @Override
    @Mapping(target = "gidgrp", ignore = true)
    @Mapping(target = "oldgidgrp", ignore = true)
    void voUpdateToBo(GetcanStoreVo vo, @MappingTarget GetcanStoreBo bo);

    @AfterMapping
    default void afterUpdate(GetcanStoreVo vo, @MappingTarget GetcanStoreBo bo) {
        bo.getGidgrp().getRec().setPurcan(vo.getGidgrp().getRec().getPurcan());
        bo.getGidgrp().getRec().setClsdat(vo.getGidgrp().getRec().getClsdat());
    }

    /**
     * Bo转为Vo
     *
     * @param bo
     * @return 返回Vo
     */
    @Override
    GetcanStoreVo boTransferToVo(GetcanStoreBo bo);

    /**
     * bo追加更新至Bo
     *
     * @param bo
     * @param vo
     */
    @Override
    void boUpdateToVo(GetcanStoreBo bo, @MappingTarget GetcanStoreVo vo);
}
